SPECIAL_CHAR = '§'


# COLORS
BLACK = SPECIAL_CHAR + '0'
DARK_BLUE = SPECIAL_CHAR + '1'
DARK_GREEN = SPECIAL_CHAR + '2'
DARK_AQUA = SPECIAL_CHAR + '3'
DARK_RED = SPECIAL_CHAR + '4'
DARK_PURPLE = SPECIAL_CHAR + '5'
GOLD = SPECIAL_CHAR + '6'
GRAY = SPECIAL_CHAR + '7'
DARK_GRAY = SPECIAL_CHAR + '8'
BLUE = SPECIAL_CHAR + '9'
GREEN = SPECIAL_CHAR + 'a'
AQUA = SPECIAL_CHAR + 'b'
RED = SPECIAL_CHAR + 'c'
LIGHT_PURPLE = SPECIAL_CHAR + 'd'
YELLOW = SPECIAL_CHAR + 'e'
WHITE = SPECIAL_CHAR + 'f'
MINECOIN_GOLD = SPECIAL_CHAR + 'g'


# FORMATTING
OBFUSCATED = SPECIAL_CHAR + 'k'
BOLD = SPECIAL_CHAR + 'l'
STRIKETHROUGH = SPECIAL_CHAR + 'm'
UNDERLINE = SPECIAL_CHAR + 'n'
ITALIC = SPECIAL_CHAR + 'o'

# RESET
RESET = SPECIAL_CHAR + 'r'
